SyncInitial class
The state before any synchronization tasks have been initiated.
- Inheritance
- Available extensions
Constructors
- SyncInitial(SyncNode mainNode)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFinished → bool
-
Available on SyncState, provided by the SyncStateX extension
no setter - isInitial → bool
-
Available on SyncState, provided by the SyncStateX extension
no setter - isInProgress → bool
-
Available on SyncState, provided by the SyncStateX extension
no setter - isPaused → bool
-
Available on SyncState, provided by the SyncStateX extension
no setter - isStopped → bool
-
Available on SyncState, provided by the SyncStateX extension
no setter - mainNode → SyncNode
-
The root node of the synchronization tree.
finalinherited
- progress → double
-
Returns the normalized progress (0.0 to 1.0) of the entire synchronization tree.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - summary → SyncSummary
-
Aggregates the overall summary of the entire synchronization tree.
no setterinherited
Methods
-
findNode(
String targetKey) → SyncNode? -
Recursively searches for a SyncNode by its
targetKeywithin the tree.inherited -
getNode(
String key) → SyncNode? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited